@@ -72,8 +72,21 @@ if __name__ == '__main__':
 
 	import serial.tools.list_ports
 	ports = list(serial.tools.list_ports.comports())
+	
+	pid = '1366'
+	hid = '1015'
+
+	for p in ports:
+		print('Serial port found:')
+		print(p[1])
+		print('Port pid and hid')
+		print(p.hwid)
+		hwid_save = p.hwid
+		if pid and hid in p.hwid:
+			print('Found the device to open with PID = {} and HID = {}!'.format(pid, hid))
 	try:
-		ser_addr = [x for x in ports if x[1]=='J-Link OB'][0][0]
+		# ser_addr = [x for x in ports if x[1]=='J-Link OB'][0][0]
+		ser_addr = [x for x in ports if pid and hid in x.hwid][0][0]
 	except IndexError:
 		print('No serial address found.\n Is the thunderboard connected using USB?') 
 		if os_platform in ['Darwin', 'Linux']:
@@ -115,7 +128,7 @@ if __name__ == '__main__':
 	while(elapsed_time < run_time):
 		t = str(ser.readline())
 		if len(t) == 3:
-			print('Serial read timeout. \n Is the bluetooth app connected and diplaying Environmental data?')
+			print('Serial read timeout. \n Is the bluetooth app connected AND diplaying Environmental data?')
 			sys.exit(2)		
 		
 		elapsed_time = (TimestampMillisec64() - t_start) / 1000
